// Persistence of Vision Ray Tracer Scene Description File
// File: sp_torus.pov
// Vers: 3.5
// Desc: Example file
// Date: 08.04.03 (dd.mm.yy)
// Auth: Tim Nikias Wenclawiak - www.NoLights.de
// Last Update: 22.07.08 (dd.mm.yy)

//Description
//A little torus is spun around and rotates about its own
//center. This movement affects and creates waves.

//Originally Used Commandline options:
//+KFI1 +KFF150 +AM2 +A0.3 +R1 +W512 +H384

#include "lssm.inc"

global_settings{
 max_trace_level 10
 assumed_gamma 1
 ambient_light 1
 photons{
  spacing .1
  autostop .25
  }
 }

camera{
 location <3,7+3*clock,-7+3*clock>
 look_at <0,-1,0>
 }
light_source{<-9,28,19> rgb 1
 spotlight point_at <0,0,0> radius 10 falloff 20
 //area_light x*5,y*5,7,7 orient circular
 }

sky_sphere{pigment{gradient y color_map{[0 rgb .7][.5 rgb <0,.4,.8>][1 rgb <0,0,.3>]}scale 2 translate -1}}

//Basic Animation Setup
#declare LSS_Debug=on;
#declare Animation_FPS=25;
#declare Animation_Time=Total_Frames/Animation_FPS;

//Water Setup
#declare LSS_FileHandle = "sp_torus"
#declare LSS_Beg=.25;
#declare LSS_End=Animation_Time;

#declare LSS_StepAmount=(LSS_End-LSS_Beg)*Animation_FPS;
#declare LSS_NPU=5;

#declare LSS_Corner_1=<-3,0,-3>;
#declare LSS_Corner_2=<-3,0, 3>;
#declare LSS_Corner_3=< 3,0, 3>;
#declare LSS_Above=<0,1,0>+LSS_Corner_1;

#declare LSS_ClipHeight=0;
#declare LSS_Seed=1;
#declare LSS_CleanUp=25;
#declare LSS_Mesh_Support=1;
#declare LSS_Obj_Memory=5;

LSS_Start(LSS_FileHandle)

#macro Torus(X)
 torus{1,.25
  pigment{checker color rgb 0 color rgb 1 scale .26}
  finish{
   specular .8 roughness .002
   brilliance 3
   reflection{0,.3 falloff 2} conserve_energy
   }
  }
#end

#macro Torus_Transform(X)
 transform{
  rotate <360,720,360>*X
  scale .5
  translate x*1.5
  rotate -y*360*X
  }
#end

LSS_Object(LSS_FileHandle,array[1]{"Torus"},array[1]{<.25,2.25>},<0,0>,<8,.05>,.0025)
Place_LSS_Objects(clock*Animation_Time)

LSS_Stop(LSS_FileHandle)

object{
 LSS_Visualize(LSS_FileHandle)
 texture{
  pigment{rgbt <.2,.3,.4,.8>}
  finish{
   specular 6 roughness .0001
   reflection{0,1 fresnel} conserve_energy
   brilliance 4
   }
 }
 interior{ior 1.44 fade_distance .25 fade_power 2 fade_color <0,.1,.2>}
 photons{target reflection on refraction on}
 }

//The surrounding box
difference{
 box{<-3.5,-3.5,-3.5><3.5,.75,3.5>}
 box{<-3,-3,-3><3,3,3>}
 pigment{checker rgb <.2,0,0> rgb <.5,.5,1> scale .999}
 }